==> tkscanfax-1.1.4%2C1.tbz: lib/tkscanfax1/fax-queue.tcl <==
# This file is a part of TkFax.
#  3 Nov 2002 hylafax
# 16 Dec 2001 modified by Masaki Shinomiya <shino@pos.to>
# efax with LPRng

proc fax_queue_window {} {
    global fax m

    if { $fax(faxqueue) == {} } {
       set q [tk_dialog .dialog "TkFax Dialog" \
                  "$m(unable_function)"  {error} 0 $m(ok)]
      return
    }
    if [info exist fax(mwn)] {
        set wn $fax(mwn).faxq
        set wnn $wn
        if [winfo exist $wn] { return }
        toplevel $wn
        wm title $wn "TkFax: Fax Queue"
    } else {
        set wn {}
        set wnn .
        wm title . "TkFax: Fax Queue"
    }

    # Label
    frame $wn.0 -bd 5
    pack $wn.0 -side top -fill x
    label $wn.0.0 -text "TkFax: Fax Queue Window" \
          -padx 10 -pady 2 -relief ridge
    pack $wn.0.0 -side left -fill x -expand yes

    # List of fax jobs
    frame $wn.1
    pack $wn.1 -side top -fill x

    frame $wn.1.0
    label $wn.1.0.1 -text $m(job_list) -anchor w -width 7 -padx 4
    radiobutton $wn.1.0.2 -command fax_queue_update \
                -variable fax(queueshowjobs) -value w -text $m(wating)
    radiobutton $wn.1.0.3 -command fax_queue_update \
                -variable fax(queueshowjobs) -value o -text $m(old)
    radiobutton $wn.1.0.4 -command fax_queue_update \
                -variable fax(queueshowjobs) -value s -text $m(susp)
    radiobutton $wn.1.0.5 -command fax_queue_update \
                -variable fax(queueshowjobs) -value a -text $m(all)
    button $wn.1.0.a -text $m(update) -command fax_queue_update -width 6 -pady 1
    label $wn.1.0.b -text $m(sec) -width 3 -anchor w
    entry $wn.1.0.c -textvariable fax(queueautoupdateperiod) -width 3 \
          -fg blue -font $fax(f1)
    checkbutton $wn.1.0.d -variable fax(queueautoupdate) -text $m(update_every)
    pack $wn.1.0.1 $wn.1.0.2 $wn.1.0.3 $wn.1.0.4 $wn.1.0.5 -side left
    pack $wn.1.0.a $wn.1.0.b $wn.1.0.c $wn.1.0.d -side right

    frame $wn.1.1

 switch -- $fax(faxagent) {
 sendfax {
    label $wn.1.1.1 -text $m(job_id)  -anchor w -width 10 -padx 3 -relief ridge
    label $wn.1.1.2 -text $m(status)  -anchor w -width 10 -padx 3 -relief ridge
    label $wn.1.1.3 -text $m(queued_by) -anchor w -width 10 -padx 3 -relief ridge
    label $wn.1.1.4 -text $m(to)      -anchor w -width 17 -padx 3 -relief ridge
    label $wn.1.1.5 -text $m(pages)   -anchor w -width 6  -padx 3 -relief ridge
    label $wn.1.1.6 -text $m(history) -anchor w -width 12 -padx 3 -relief ridge

    text $wn.1.2 -width 72 -height 10 -state disabled \
         -xscroll "$wn.1.3 set" -yscroll "$wn.1.4 set" \
         -tabs {2.8c left 5.6c left 8.3c left 12.8c left 14.3c left 18c} \
         -wrap none -relief sunken -font $fax(f1) -fg $fax(c1)
    pack $wn.1.1.1 $wn.1.1.2 $wn.1.1.3 $wn.1.1.4 $wn.1.1.5 $wn.1.1.6\
         -side left -fill x
    }
 efax {
    label $wn.1.1.1 -text $m(rank)  -anchor w -width 8 -padx 3 -relief ridge
    label $wn.1.1.2 -text $m(owner_id)  -anchor w -width 24 -padx 3 -relief ridge
#    label $wn.1.1.3 -text $m(class) -anchor w -width 6 -padx 3 -relief ridge
    label $wn.1.1.4 -text $m(job_id)      -anchor w -width 6 -padx 3 -relief ridge
    label $wn.1.1.5 -text "Files/Size/Time"   -anchor w -width 34 -padx 3 -relief ridge

    text $wn.1.2 -width 72 -height 10 -state disabled \
         -xscroll "$wn.1.3 set"  -yscroll "$wn.1.4 set" \
         -tabs {2c left 7.2c left 8.8c} \
         -wrap none -relief sunken -font $fax(f1) -fg $fax(c1)

    pack $wn.1.1.1 $wn.1.1.2 $wn.1.1.4 $wn.1.1.5\
         -side left -fill x
    }
 hylafax {
    label $wn.1.1.1 -text $m(job_id)  -anchor w -width 6 -padx 3 -relief ridge
    label $wn.1.1.2 -text Pri -anchor w -width 4 -padx 3 -relief ridge
    label $wn.1.1.3 -text S -anchor w -width 2 -padx 3 -relief ridge
    label $wn.1.1.4 -text $m(queued_by)  -anchor w -width 8 -padx 3 -relief ridge
    label $wn.1.1.5 -text $m(to) -anchor w -width 15 -padx 3 -relief ridge
    label $wn.1.1.6 -text $m(pages)   -anchor w -width 6  -padx 3 -relief ridge
    label $wn.1.1.7 -text Dials -anchor w -width 4 -padx 3 -relief ridge
    label $wn.1.1.8 -text TTSend -anchor w -width 4 -padx 3 -relief ridge
    label $wn.1.1.9 -text $m(status)  -anchor w -width 15 -padx 3 -relief ridge

    text $wn.1.2 -width 72 -height 10 -state disabled \
         -xscroll "$wn.1.3 set" -yscroll "$wn.1.4 set" \
         -tabs {1.5c left 2.8c left 3.5c left 5.2c left 8.7c left 10.2c left 11.2c left 12.5c left} \
         -wrap none -relief sunken -font $fax(f1) -fg $fax(c1)
    pack $wn.1.1.1 $wn.1.1.2 $wn.1.1.3 $wn.1.1.4 $wn.1.1.5 $wn.1.1.6\
        $wn.1.1.7 $wn.1.1.8 $wn.1.1.9\
         -side left -fill x
    }
  }
    set fax(queuelist) $wn.1.2
    scrollbar $wn.1.3 -command "$wn.1.2 xview" -orient horizontal
    scrollbar $wn.1.4 -command "$wn.1.2 yview"

    label $wn.1.5 -text "" -padx 7 -pady 0 -relief sunken
    label $wn.1.6 -text "" -padx 7 -pady 0 -relief sunken

    grid $wn.1.0 -row 0 -column 0 -rowspan 1 -columnspan 2 -sticky news
    grid $wn.1.1 -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.2 -row 2 -column 0 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.3 -row 3 -column 0 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.4 -row 2 -column 1 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.5 -row 3 -column 1 -rowspan 1 -columnspan 1
    grid $wn.1.6 -row 1 -column 1 -rowspan 1 -columnspan 1

    # Message
    label $wn.2 -width 72 -pady 4 -relief ridge -anchor w \
          -wraplength 7.2i -justify left
    set fax(queuemessage) $wn.2
    pack $wn.2 -side top -fill x

    # Buttons
    frame $wn.3 -bd 10
    pack $wn.3 -side top -fill x -expand yes
    button $wn.3.2 -text $m(delete) -width 8 -command fax_queue_delete
    button $wn.3.3 -text $m(view)   -width 8 -command fax_queue_view
    button $wn.3.4 -text $m(close)  -width 8 -command "destroy $wnn"
    pack $wn.3.2 $wn.3.3 $wn.3.4 -side left -fill x -expand yes

    # does not work 'view' for efax
 switch -- $fax(faxagent) {
 sendfax {
   	bind $fax(queuelist) <Double-Button> fax_queue_view
	}
 efax -
 hylafax {
		foreach i "$wn.1.0.2 $wn.1.0.3 $wn.1.0.4 $wn.1.0.5 $wn.3.3" {
			$i configure -state disabled
		}
	}
 }

    # Mouse bindings
    bind $fax(queuelist) <Button> fax_queue_setcur
    #bind $fax(queuelist) <Double-Button> fax_queue_view

    # Initialization
    fax_queue_autoupdate
}

proc fax_queue_update {} {
    global fax m

    # Clear the job list window.
    $fax(queuelist) configure -state normal
    $fax(queuelist) delete 1.0 end

    # Get the job list from fax outgoing directory.
    set fax(jobindex) 0
    set nj 0
    set jobid ""
    set status ""
    set queuedby ""
    set destination ""
    set pages ""
    set STATUS ""

    # branch on the fax agent ####################
  switch -- $fax(faxagent)  {

  sendfax { ;#################
    set fax(jobindex) 0
    set fax(pageindex) 4
    set fax(statusindex) 5
    switch $fax(queueshowjobs) {
        o {set jobopt "-o"}
        s {set jobopt "-s"}
        a {set jobopt "-a"}
        default {set jobopt ""}
    }
    set command "$fax(faxqueue) -v $jobopt"
    set faxq [open "|$command"]

    # Display the job list.
    while 1 {
        set qline [gets $faxq]
        if { $qline== "no jobs."} {
            fax_queue_message "No jobs."
            break
        }
        if {$qline==""} {
            set iline \
            "$jobid\t$status\t$queuedby\t$destination\t$pages\t$STATUS"
            if {$nj && $status!="log"} { $fax(queuelist) insert end $iline\n }
            # Get the last run time of faxrunq.
            set qline [gets $faxq]
            fax_queue_message $qline
            break
        }
        if {[string index $qline 0]=="F"} {
            set iline \
            "$jobid\t$status\t$queuedby\t$destination\t$pages\t$STATUS"
            if {$nj && $status!="log"} { $fax(queuelist) insert end $iline\n }
            incr nj
            set jobid [string range $qline 0 6]
            set status [string range $qline 12 [expr [string last : $qline]-1]]
            if {$status==""} {set status wating}
            set queuedby ""
            set destination ""
            set pages ""
            set STATUS ""
        } else {
            set p [string first : $qline]
            set tag [string range $qline 0 [expr $p-1]]
            set con [string range $qline [expr $p+2] end]
            switch $tag {
                "        Queued by" -
                "\tQueued by" {set queuedby $con}
                "               to" -
                "\t       to" {set destination $con}
                "            Input" -
                "\t    Input" {}
                "            Pages" -
                "\t    Pages" {
                    set lastfile [lindex $con [expr [llength $con]-1]]
                    set pages [string range $lastfile 1 \
                                  [expr [string first .  $lastfile]-1]]
                }
                "           Status" -
                "\t   Status" {append STATUS "$con\t"}
                default {}
            }
        }
    }
    # Finished.
    catch { close $faxq }
    }

  efax {  ;####################################
    set fax(jobindex) 2
    set fax(pageindex) 4
    set fax(statusindex) 3
    set user ""
    if [ fax_exec "id -u" ] { set user [ fax_exec "id -un" ] }
    set command "$fax(faxqueue) $user"
    set faxq [open "|$command" r]
    set qline [ gets $faxq ]
    if { [lindex $qline 0] == "no" } {
          fax_queue_message $qline
    } else {
         fax_queue_message ""
         while { ! [eof $faxq] &&  [lindex $qline 0] != "Rank" } {
             set qline [ gets $faxq ] 
         }
         set header $qline
         set i 0 
         while { $i <= 3 } {
             if { [ lindex $header $i ] == "Job" } {
                    set jobpos $i
                    break
             }
             set i [ expr $i+1 ]
         }
         while { ! [eof $faxq] } {
              set qline [ gets $faxq ] 
              if { $qline != "" } {
                    set iline ""
                    set i 0
                    set e [ llength $qline ]
                    while { $i <= $e } {
                        set item [ lindex $qline $i ]
                        if { $i <= $jobpos } {
                                      set s "\t"
                            } elseif {$i ==  $e } {
                                      set s "\n"
                            } else   { set s " " }
                        if { ! ( $i == 2 && $jobpos != 2 ) } {
                            set iline "$iline$item$s"
                        }
                        set i [ expr $i+1 ]
                    }
                    $fax(queuelist) insert end $iline
              }
          } 
      }
     catch { close $faxq }
     }

  hylafax {  ;####################################
    set fax(jobindex) 0
    set fax(pageindex) 5
    set fax(statusindex) 8
    set command "faxstat -s"
    set faxq [open "|$command" r]
    	set qline [ gets $faxq ]
        set header $qline
	set nline 0
         while { ! [eof $faxq] } {
              set qline [ gets $faxq ] 
              if { $qline != "" } {
                    #$fax(queuelist) insert end "$qline\n"
                    set e [expr [ llength $qline ] - 1 ]
			set iline "" 
			set i 0
			foreach item $qline {
				if { $i == $e } { set s "\n" } elseif { $i < 8 } { set s "\t" } else  { set s " " } 
				if { $i ==  5 || $i == 6 } { regsub -- {:} $item {/} item } 
				set iline "$iline$item$s"
				incr i
			}
			set key [ lindex $qline 0 ]
			switch -glob -- $key {
				[1-9]* { $fax(queuelist) insert end "$iline" ; incr nline }
			}
              }
          } 
	if { $nline < 1 } { $fax(queuelist) insert end "$header" }
      catch { close $faxq }
     }
  }

    $fax(queuelist) delete {end -1 char}
    $fax(queuelist) configure -state disabled
    set fax(queue-jobid) ""
    set fax(queue-pages) ""
}

proc fax_queue_autoupdate {} {
    global fax
    if [winfo exist $fax(queuelist)] {
        fax_queue_update
    }
    if {[winfo exist $fax(queuelist)] && $fax(queueautoupdate)} {
        after [expr $fax(queueautoupdateperiod)*1000] fax_queue_autoupdate
    }
}

proc fax_queue_message { msg } {
    global fax
    $fax(queuemessage) configure -text $msg
}

proc fax_queue_setcur {} {
    global fax
    $fax(queuelist) tag delete cur
    $fax(queuelist) tag configure cur -foreground red -background skyblue
    $fax(queuelist) tag add cur {current linestart} {current lineend +1 char}
    set line [$fax(queuelist) get {current linestart} {current lineend}]
    set elements [split $line \t]
    set fax(queue-jobid) [lindex $elements $fax(jobindex)]
    set fax(queue-pages) [lindex $elements $fax(pageindex)]
    for {set status "";set i $fax(statusindex)} {$i<[llength $elements]} {incr i} {
        append status "[lindex $elements $i]\n"
    }
    fax_queue_message [string range $status 0 [expr [string length $status]-2]]
}

proc fax_queue_delete {} {
#
# Delete a selected outgoing fax from spool area.
#
    global fax m
    if {$fax(queue-jobid) != {}} {
        set k [tk_dialog .dialog "TkFax: Queue Delete" \
        "$m(delete_a_job) $fax(queue-jobid)?" {warning} 0 $m(confirm) $m(cancel)]
        if {$k==1} { return }
        fax_exec_flag "$fax(faxrm) $fax(queue-jobid)"
        fax_queue_update
    }
}

proc fax_queue_view {} {
#
# View a selected outgoing fax.
#
    global fax
    if {$fax(queue-jobid) != {}} {
        for {set faxes ""; set i 1} {$i<=$fax(queue-pages)} {incr i} {
            append  faxes " $fax(spooldir)/outgoing/$fax(queue-jobid)/f$i.g3"
        }
        fax_view_fax $faxes
    }
}

==> tkscanfax-1.1.8_1%2C1.tbz: lib/tkscanfax1/fax-queue.tcl <==
# This file is a part of TkFax.
# 10 Feb 2005 remote efax
#  2 Feb 2005 when fax agent is none
# 26 Mar 2004 fix typo of 'waiting'
#  3 Nov 2002 hylafax
# 16 Dec 2001 modified by Masaki Shinomiya <shino@pos.to>
# efax with LPRng

proc fax_queue_window {} {
    global fax m

    if { $fax(faxqueue) == {} } {
       set q [tk_dialog .dialog "TkFax Dialog" \
                  "$m(unable_function)"  {error} 0 $m(ok)]
      return
    }
    if [info exist fax(mwn)] {
        set wn $fax(mwn).faxq
        set wnn $wn
        if [winfo exist $wn] { return }
        toplevel $wn
        wm title $wn "TkFax: Fax Queue"
    } else {
        set wn {}
        set wnn .
        wm title . "TkFax: Fax Queue"
    }

    # Label
    frame $wn.0 -bd 5
    pack $wn.0 -side top -fill x
    label $wn.0.0 -text "TkFax: Fax Queue Window" \
          -padx 10 -pady 2 -relief ridge
    pack $wn.0.0 -side left -fill x -expand yes

    # List of fax jobs
    frame $wn.1
    pack $wn.1 -side top -fill x

    frame $wn.1.0
    label $wn.1.0.1 -text $m(job_list) -anchor w -width 7 -padx 4
    radiobutton $wn.1.0.2 -command fax_queue_update \
                -variable fax(queueshowjobs) -value w -text $m(waiting)
    radiobutton $wn.1.0.3 -command fax_queue_update \
                -variable fax(queueshowjobs) -value o -text $m(old)
    radiobutton $wn.1.0.4 -command fax_queue_update \
                -variable fax(queueshowjobs) -value s -text $m(susp)
    radiobutton $wn.1.0.5 -command fax_queue_update \
                -variable fax(queueshowjobs) -value a -text $m(all)
    button $wn.1.0.a -text $m(update) -command fax_queue_update -width 6 -pady 1
    label $wn.1.0.b -text $m(sec) -width 3 -anchor w
    entry $wn.1.0.c -textvariable fax(queueautoupdateperiod) -width 3 \
          -fg blue -font $fax(f1)
    checkbutton $wn.1.0.d -variable fax(queueautoupdate) -text $m(update_every)
    pack $wn.1.0.1 $wn.1.0.2 $wn.1.0.3 $wn.1.0.4 $wn.1.0.5 -side left
    pack $wn.1.0.a $wn.1.0.b $wn.1.0.c $wn.1.0.d -side right

    frame $wn.1.1

 switch -- $fax(faxagent) {
 sendfax {
    label $wn.1.1.1 -text $m(job_id)  -anchor w -width 10 -padx 3 -relief ridge
    label $wn.1.1.2 -text $m(status)  -anchor w -width 10 -padx 3 -relief ridge
    label $wn.1.1.3 -text $m(queued_by) -anchor w -width 10 -padx 3 -relief ridge
    label $wn.1.1.4 -text $m(to)      -anchor w -width 17 -padx 3 -relief ridge
    label $wn.1.1.5 -text $m(pages)   -anchor w -width 6  -padx 3 -relief ridge
    label $wn.1.1.6 -text $m(history) -anchor w -width 12 -padx 3 -relief ridge

    text $wn.1.2 -width 72 -height 10 -state disabled \
         -xscroll "$wn.1.3 set" -yscroll "$wn.1.4 set" \
         -tabs {2.8c left 5.6c left 8.3c left 12.8c left 14.3c left 18c} \
         -wrap none -relief sunken -font $fax(f1) -fg $fax(c1)
    pack $wn.1.1.1 $wn.1.1.2 $wn.1.1.3 $wn.1.1.4 $wn.1.1.5 $wn.1.1.6\
         -side left -fill x
    }
 hylafax {
    label $wn.1.1.1 -text $m(job_id)  -anchor w -width 6 -padx 3 -relief ridge
    label $wn.1.1.2 -text Pri -anchor w -width 4 -padx 3 -relief ridge
    label $wn.1.1.3 -text S -anchor w -width 2 -padx 3 -relief ridge
    label $wn.1.1.4 -text $m(queued_by)  -anchor w -width 8 -padx 3 -relief ridge
    label $wn.1.1.5 -text $m(to) -anchor w -width 15 -padx 3 -relief ridge
    label $wn.1.1.6 -text $m(pages)   -anchor w -width 6  -padx 3 -relief ridge
    label $wn.1.1.7 -text Dials -anchor w -width 4 -padx 3 -relief ridge
    label $wn.1.1.8 -text TTSend -anchor w -width 4 -padx 3 -relief ridge
    label $wn.1.1.9 -text $m(status)  -anchor w -width 15 -padx 3 -relief ridge

    text $wn.1.2 -width 72 -height 10 -state disabled \
         -xscroll "$wn.1.3 set" -yscroll "$wn.1.4 set" \
         -tabs {1.5c left 2.8c left 3.5c left 5.2c left 8.7c left 10.2c left 11.2c left 12.5c left} \
         -wrap none -relief sunken -font $fax(f1) -fg $fax(c1)
    pack $wn.1.1.1 $wn.1.1.2 $wn.1.1.3 $wn.1.1.4 $wn.1.1.5 $wn.1.1.6\
        $wn.1.1.7 $wn.1.1.8 $wn.1.1.9\
         -side left -fill x
    }
 efax -
 remote_efax -
 default {
    label $wn.1.1.1 -text $m(rank)  -anchor w -width 8 -padx 3 -relief ridge
    label $wn.1.1.2 -text $m(owner_id)  -anchor w -width 24 -padx 3 -relief ridge
#    label $wn.1.1.3 -text $m(class) -anchor w -width 6 -padx 3 -relief ridge
    label $wn.1.1.4 -text $m(job_id)      -anchor w -width 6 -padx 3 -relief ridge
    label $wn.1.1.5 -text "Files/Size/Time"   -anchor w -width 34 -padx 3 -relief ridge

    text $wn.1.2 -width 72 -height 10 -state disabled \
         -xscroll "$wn.1.3 set"  -yscroll "$wn.1.4 set" \
         -tabs {2c left 7.2c left 8.8c} \
         -wrap none -relief sunken -font $fax(f1) -fg $fax(c1)

    pack $wn.1.1.1 $wn.1.1.2 $wn.1.1.4 $wn.1.1.5\
         -side left -fill x
    }
  }
    set fax(queuelist) $wn.1.2
    scrollbar $wn.1.3 -command "$wn.1.2 xview" -orient horizontal
    scrollbar $wn.1.4 -command "$wn.1.2 yview"

    label $wn.1.5 -text "" -padx 7 -pady 0 -relief sunken
    label $wn.1.6 -text "" -padx 7 -pady 0 -relief sunken

    grid $wn.1.0 -row 0 -column 0 -rowspan 1 -columnspan 2 -sticky news
    grid $wn.1.1 -row 1 -column 0 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.2 -row 2 -column 0 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.3 -row 3 -column 0 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.4 -row 2 -column 1 -rowspan 1 -columnspan 1 -sticky news
    grid $wn.1.5 -row 3 -column 1 -rowspan 1 -columnspan 1
    grid $wn.1.6 -row 1 -column 1 -rowspan 1 -columnspan 1

    # Message
    label $wn.2 -width 72 -pady 4 -relief ridge -anchor w \
          -wraplength 7.2i -justify left
    set fax(queuemessage) $wn.2
    pack $wn.2 -side top -fill x

    # Buttons
    frame $wn.3 -bd 10
    pack $wn.3 -side top -fill x -expand yes
    button $wn.3.2 -text $m(delete) -width 8 -command fax_queue_delete
    button $wn.3.3 -text $m(view)   -width 8 -command fax_queue_view
    button $wn.3.4 -text $m(close)  -width 8 -command "destroy $wnn"
    pack $wn.3.2 $wn.3.3 $wn.3.4 -side left -fill x -expand yes

    # does not work 'view' for efax
 switch -- $fax(faxagent) {
 sendfax {
   	bind $fax(queuelist) <Double-Button> fax_queue_view
	}
 remote_efax -
 efax -
 hylafax -
 default {
		foreach i "$wn.1.0.2 $wn.1.0.3 $wn.1.0.4 $wn.1.0.5 $wn.3.3" {
			$i configure -state disabled
		}
	}
 }

    # Mouse bindings
    bind $fax(queuelist) <Button> fax_queue_setcur
    #bind $fax(queuelist) <Double-Button> fax_queue_view

    # Initialization
    fax_queue_autoupdate
}

proc fax_queue_update {} {
    global fax m

    # Clear the job list window.
    $fax(queuelist) configure -state normal
    $fax(queuelist) delete 1.0 end

    # Get the job list from fax outgoing directory.
    set fax(jobindex) 0
    set nj 0
    set jobid ""
    set status ""
    set queuedby ""
    set destination ""
    set pages ""
    set STATUS ""

  # branch on the fax agent ####################
  switch -- $fax(faxagent)  {

  sendfax { ;#################
    set fax(jobindex) 0
    set fax(pageindex) 4
    set fax(statusindex) 5
    switch $fax(queueshowjobs) {
        o {set jobopt "-o"}
        s {set jobopt "-s"}
        a {set jobopt "-a"}
        default {set jobopt ""}
    }
    set command "$fax(faxqueue) -v $jobopt"
    set faxq [open "|$command"]

    # Display the job list.
    while 1 {
        set qline [gets $faxq]
        if { $qline== "no jobs."} {
            #fax_queue_message "$m(no_fax_in_queue)"
            break
        }
        if {$qline==""} {
            set iline \
            "$jobid\t$status\t$queuedby\t$destination\t$pages\t$STATUS"
            if {$nj && $status!="log"} { $fax(queuelist) insert end $iline\n }
            # Get the last run time of faxrunq.
            set qline [gets $faxq]
            fax_queue_message $qline
            break
        }
        if {[string index $qline 0]=="F"} {
            set iline \
            "$jobid\t$status\t$queuedby\t$destination\t$pages\t$STATUS"
            if {$nj && $status!="log"} { $fax(queuelist) insert end $iline\n }
            incr nj
            set jobid [string range $qline 0 6]
            set status [string range $qline 12 [expr [string last : $qline]-1]]
            if {$status==""} {set status waiting}
            set queuedby ""
            set destination ""
            set pages ""
            set STATUS ""
        } else {
            set p [string first : $qline]
            set tag [string range $qline 0 [expr $p-1]]
            set con [string range $qline [expr $p+2] end]
            switch $tag {
                "        Queued by" -
                "\tQueued by" {set queuedby $con}
                "               to" -
                "\t       to" {set destination $con}
                "            Input" -
                "\t    Input" {}
                "            Pages" -
                "\t    Pages" {
                    set lastfile [lindex $con [expr [llength $con]-1]]
                    set pages [string range $lastfile 1 \
                                  [expr [string first .  $lastfile]-1]]
                }
                "           Status" -
                "\t   Status" {append STATUS "$con\t"}
                default {}
            }
        }
    }
    # Finished.
    catch { close $faxq }
    }

  hylafax {  ;####################################
    set fax(jobindex) 0
    set fax(pageindex) 5
    set fax(statusindex) 8
    set command "faxstat -s"
    set faxq [open "|$command" r]
    	set qline [ gets $faxq ]
        set header $qline
	set nline 0
         while { ! [eof $faxq] } {
              set qline [ gets $faxq ] 
              if { $qline != "" } {
                    incr nj
                    #$fax(queuelist) insert end "$qline\n"
                    set e [expr [ llength $qline ] - 1 ]
			set iline "" 
			set i 0
			foreach item $qline {
				if { $i == $e } { set s "\n" } elseif { $i < 8 } { set s "\t" } else  { set s " " } 
				if { $i ==  5 || $i == 6 } { regsub -- {:} $item {/} item }
				set iline "$iline$item$s"
				incr i
			}
			set key [ lindex $qline 0 ]
			switch -glob -- $key {
				[1-9]* { $fax(queuelist) insert end "$iline" ; incr nline }
			}
              }
          }
	if { $nline < 1 } { $fax(queuelist) insert end "$header" }
      catch { close $faxq }
     }
  remote_efax -
  efax -
  default {  ;####################################
    set fax(jobindex) 2
    set fax(pageindex) 4
    set fax(statusindex) 3
    set user ""
    if [ fax_exec "id -u" ] { set user [ fax_exec "id -un" ] }
    set command "$fax(faxqueue) $user"
    set faxq [open "|$command" r]
    set qline [ gets $faxq ]
    if { [lindex $qline 0] == "no" } {
          #fax_queue_message $qline
    } else {
         fax_queue_message ""
         while { ! [eof $faxq] &&  [lindex $qline 0] != "Rank" } {
             set qline [ gets $faxq ]
         }
         set header $qline
         set i 0
         while { $i <= 3 } {
             if { [ lindex $header $i ] == "Job" } {
                    set jobpos $i
                    break
             }
             set i [ expr $i+1 ]
         }
         while { ! [eof $faxq] } {
              set qline [ gets $faxq ]
              if { $qline != "" } {
                    set iline ""
                    set i 0
                    set e [ llength $qline ]
                    while { $i <= $e } {
                        set item [ lindex $qline $i ]
                        if { $i <= $jobpos } {
                                      set s "\t"
                            } elseif {$i ==  $e } {
                                      set s "\n"
                            } else   { set s " " }
                        if { ! ( $i == 2 && $jobpos != 2 ) } {
                            set iline "$iline$item$s"
                        }
                        set i [ expr $i+1 ]
                    }
		    incr nj
                    $fax(queuelist) insert end $iline
              }
          }
      }
     catch { close $faxq }
     }
   }
  # ************************************************************

    $fax(queuelist) delete {end -1 char}
    fax_debug "Number of queue=$nj"
    if { $nj < 1 } {
	#$fax(queuelist) insert end "$m(no_fax_in_queue)"
        fax_queue_message "$m(no_fax_in_queue)"
    }
    $fax(queuelist) configure -state disabled
    set fax(queue-jobid) ""
    set fax(queue-pages) ""
}

proc fax_queue_autoupdate {} {
    global fax
    if [winfo exist $fax(queuelist)] {
        fax_queue_update
    }
    if {[winfo exist $fax(queuelist)] && $fax(queueautoupdate)} {
        after [expr $fax(queueautoupdateperiod)*1000] fax_queue_autoupdate
    }
}

proc fax_queue_message { msg } {
    global fax
    $fax(queuemessage) configure -text $msg
}

proc fax_queue_setcur {} {
    global fax
    $fax(queuelist) tag delete cur
    $fax(queuelist) tag configure cur -foreground red -background skyblue
    $fax(queuelist) tag add cur {current linestart} {current lineend +1 char}
    set line [$fax(queuelist) get {current linestart} {current lineend}]
    set elements [split $line \t]
    set fax(queue-jobid) [lindex $elements $fax(jobindex)]
    set fax(queue-pages) [lindex $elements $fax(pageindex)]
    for {set status "";set i $fax(statusindex)} {$i<[llength $elements]} {incr i} {
        append status "[lindex $elements $i]\n"
    }
    fax_queue_message [string range $status 0 [expr [string length $status]-2]]
}

proc fax_queue_delete {} {
#
# Delete a selected outgoing fax from spool area.
#
    global fax m
    if {$fax(queue-jobid) != {}} {
        set k [tk_dialog .dialog "TkFax: Queue Delete" \
        "$m(delete_a_job) $fax(queue-jobid)?" {warning} 0 $m(confirm) $m(cancel)]
        if {$k==1} { return }
        fax_exec_flag "$fax(faxrm) $fax(queue-jobid)"
        fax_queue_update
    }
}

proc fax_queue_view {} {
#
# View a selected outgoing fax.
#
    global fax
    if {$fax(queue-jobid) != {}} {
        for {set faxes ""; set i 1} {$i<=$fax(queue-pages)} {incr i} {
            append  faxes " $fax(spooldir)/outgoing/$fax(queue-jobid)/f$i.g3"
        }
        fax_view_fax $faxes
    }
}
